#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_1 = require("./cli");
const config_1 = require("./config");
const api_1 = require("./api");
const utils_1 = require("./utils");
const config = config_1.load();
(async () => {
    const [email, validToken] = await Promise.all([
        config.email || cli_1.input('Please enter your metacall email'),
        config.token && api_1.validate(config.token).catch(err => err.response
            ? utils_1.debug('Invalid token: ' + err.response.data)
            : utils_1.fatal('Could not validate token (' + err.message + ')'))
    ]);
    const password = validToken ? null :
        await cli_1.input('Please enter your metacall password', 'password');
    const token = validToken ? config.token :
        await api_1.login(email, password, config.baseURL).catch(err => err.response
            ? err.response.data === 'account does not exist'
                ? (utils_1.info(err.response.data + ', attempting to sign up'),
                    api_1.signup(email, password, config.baseURL).catch(err => err.response
                        ? utils_1.fatal('Could not sign up: ' + err.response.data)
                        : utils_1.fatal('Could not sign up (' + err.message + ')')))
                : utils_1.fatal('Could not sign in: ' + err.response.data)
            : utils_1.fatal('Could not sign in (' + err.message + ')'));
    if (!token) {
        utils_1.fatal('Wrong username or password!');
    }
    /* Rudimentary upload code
    const { readFileSync } = await import('fs');
    const uploadResult = await upload(token, readFileSync('GeoIP.zip'))
        .catch(err =>
            err.response
                ? fatal('Could not upload project: ' + err.response.data)
                : fatal('Could not upload package (' + err.response.data + ')'));

    info('Upload ' + uploadResult);
    */
    config_1.save({ email, token });
})();
